@@ -1,4 +1,5 @@
 import inspect
+from importlib import import_module
 
 from guniflask.annotation import AnnotationMetadata, AnnotationUtils
 from guniflask.beans.definition import BeanDefinition
@@ -74,10 +75,11 @@ class ConfigurationClassBeanDefinitionReader:
         meta_data = AnnotationUtils.get_annotation_metadata(source)
         if meta_data.is_annotated(Include):
             self._load_bean_definition_for_included_config(meta_data)
+
         for m in dir(source):
-            method = getattr(source, m)
-            if inspect.isfunction(method) or inspect.ismethod(method):
-                method_metadata = AnnotationUtils.get_annotation_metadata(method)
+            func = getattr(source, m)
+            if inspect.isfunction(func):
+                method_metadata = AnnotationUtils.get_annotation_metadata(func)
                 if method_metadata is not None and method_metadata.is_annotated(Bean):
                     self._load_bean_definition_for_bean_method(bean_name, method_metadata)
 
@@ -97,6 +99,9 @@ class ConfigurationClassBeanDefinitionReader:
         config_set = annotation['values']
         if config_set:
             for config_cls in config_set:
+                if isinstance(config_cls, str):
+                    _m, _c = config_cls.rsplit('.', maxsplit=1)
+                    config_cls = getattr(import_module(_m), _c)
                 config_cls_metadata = AnnotationUtils.get_annotation_metadata(config_cls)
                 if self._condition_evaluator.should_skip(config_cls_metadata):
                     continue
